/*
**  terminal.h
**
**  Structures for TERMPHON.FD, TERMPROF.FD, and TERMKEYS.FD
**
**  Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-18                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __TERMINAL_H__
#define __TERMINAL_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  TERMPHON.FD - Internal terminal telephone directory record
**
**  Note that the char[] fields are in Pascal fashion. The first byte is
**  the length byte. The actual string starts at [1] and the string is NOT
**  NUL terminated.
*/
typedef struct
    {
    char            Name[31];                                  /*System name*/
    char            Number[35];                 /*Telephone number as dialed*/
    char            Password[17];             /*Default password for session*/
    unsigned short int
                    Baud;                                        /*Baud rate*/
    unsigned long   Flags;                  /*See below under 'Entry Flags:'*/
    unsigned char   Protocol,             /*Preferred file transfer protocol*/
                    Parity,                                         /*Parity*/
                    WordLen,                        /*# of data bits, 7 or 8*/
                    StopBits,                       /*# of stop bits, 1 or 2*/
                    Emulation;                          /*Terminal emulation*/
    unsigned short int
                    KeySet,          /*Key definition record, 0xFFFF=DEFAULT*/
                    Profile;                     /*Profile record, 0=DEFAULT*/
    char            Script[9];           /*Script name to use, blank if none*/
    }
    PHONEREC;

    /* Phone record flags */

#define TPHONE_XLATON   0x00000001L                 /*Use translation tables*/
#define TPHONE_INQUEUE  0x00000002L                     /*Queued for dialing*/
#define TPHONE_LFEXPAND 0x00000004L                /*On=CR->CR/LF Off=CR->CR*/
#define TPHONE_NOWRAP   0x00000008L          /*Don't wrap lines when xpos=80*/
#define TPHONE_LECHO    0x00000010L       /*Echo keyboard input to local CRT*/
#define TPHONE_NOAVATAR 0x00000020L                    /*No AVATAR sequences*/
#define TPHONE_NOIEMSI  0x00000040L                               /*No IEMSI*/
#define TPHONE_DELETED  0x80000000L         /*Entry is deleted, never stored*/

/*
**    TERMPROF.FD - Profile record
**
**  All strings are NUL terminated, a'la C ASCIIZ strings.
*/
typedef struct
    {
    char            UserName[30];                                /*User name*/
    char            Handle[20];                                     /*Handle*/
    char            Password[20];                                 /*Password*/
    unsigned long   Flags;                /*See below under 'Profile Flags:'*/
    char            RESERVED[20];                                 /*Reserved*/
    }
    PROFILE;

    /* Profile flags (FLAGS) */

#define PRF_HOTKEYS     0x00000001L                                /*Hotkeys*/
#define PRF_QUIET       0x00000002L                          /*Don't disturb*/
#define PRF_MORE        0x00000004L                           /*Page pausing*/
#define PRF_EDITOR      0x00000008L                 /*Use full-screen editor*/
#define PRF_NEWS        0x00000010L             /*Show bulletins, news, etc.*/
#define PRF_NEWMAIL     0x00000020L                     /*Check for new mail*/
#define PRF_NEWFILE     0x00000040L                    /*Check for new files*/
#define PRF_CLRSCR      0x00000080L                        /*Screen clearing*/

/*
**  TERMKEYS.FD - Keyset record
**
**  Note that the char[] fields are in Pascal fashion. The first byte is
**  the length byte. The actual string starts at [1] and the string is NOT
**  NUL terminated.
*/
typedef struct
    {
    char            ShiftKey[12][31];                         /*Shift F1-F12*/
    char            CtrlKey[12][31];                           /*Ctrl F1-F12*/
    }
    KEYREC;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "terminal.h" */
